import React, { useState, useEffect, useRef } from "react";
import { FaArrowAltCircleLeft, FaArrowAltCircleRight } from "react-icons/fa";

const ImageSlider = ({ imageUrl, heading }) => {
  const [imageIndex, setImageIndex] = useState(0);
  const intervalRef = useRef(null);

  const prevSlide = () => {
    setImageIndex((prevIndex) =>
      prevIndex === 0 ? imageUrl.length - 1 : prevIndex - 1
    );
    resetAutoSlide();
  };

  const nextSlide = () => {
    setImageIndex((prevIndex) =>
      prevIndex === imageUrl.length - 1 ? 0 : prevIndex + 1
    );
    resetAutoSlide();
  };

  const startAutoSlide = () => {
    intervalRef.current = setInterval(() => {
      setImageIndex((prevIndex) =>
        prevIndex === imageUrl.length - 1 ? 0 : prevIndex + 1
      );
    }, 3000);
  };

  const resetAutoSlide = () => {
    if (intervalRef.current) {
      clearInterval(intervalRef.current);
    }
    startAutoSlide();
  };
  useEffect(() => {
    startAutoSlide();

    return () => clearInterval(intervalRef.current);
  }, [imageUrl.length]);

  return (
    <div className="slider-container" style={{ textAlign: "center" }}>
      <img
        src={imageUrl[imageIndex]}
        alt={`Slide ${imageIndex}`}
        className="slider-image"
      />

      <div className="slide-content-container">
        <h1> {heading[imageIndex]}</h1>
        <p>
          Lorem, ipsum dolor sit amet consectetur adipisicing elit. Magnam
          accusantium ipsa quaerat veritatis architecto, aut accusamus
          blanditiis repudiandae harum dicta.
        </p>
        <button className="content-btn">Learn More</button>
      </div>
      <button onClick={prevSlide} className="btn-left">
        <FaArrowAltCircleLeft />
      </button>

      <button onClick={nextSlide} className="btn-right">
        <FaArrowAltCircleRight />
      </button>
    </div>
  );
};

export default ImageSlider;
